@@ -34,12 +34,12 @@ from typing import Union
 
 import arrow
 import httpx
-import youtube_dl
 from feedgen.feed import FeedGenerator
 from PIL import Image
 from rich import print as rprint
 from rich import traceback
 from rich.logging import RichHandler
+from yt_dlp import YoutubeDL
 
 from playlist2podcast import __version__
 from playlist2podcast import CODE_VERSION_MAJOR
@@ -249,7 +249,7 @@ def main() -> None:
     download_options = YDL_DL_OPTS
     if config.youtube_cookie_file and config.youtube_cookie_file != "":
         download_options["cookiefile"] = config.youtube_cookie_file
-    downloader = youtube_dl.YoutubeDL(download_options)
+    downloader = YoutubeDL(download_options)
 
     for current_play_list in config.play_lists:
         logger.info(
@@ -333,7 +333,7 @@ def is_video_included(
 
 def add_episodes(
     config: Configuration,
-    downloader: youtube_dl.YoutubeDL,
+    downloader: YoutubeDL,
     feed: FeedGenerator,
     logger: logging.Logger,
     play_list_info: List[Dict[str, str]],
